@@ -4,21 +4,25 @@ use base 'IPC::PubSub::Cacheable';
 use Cache::Memcached;
 
 sub new {
-    my $class = shift;
-    my $config = shift || $class->default_config;
+    my $class       = shift;
+    my $namespace   = shift || $class;
+    my $config      = shift || $class->default_config($namespace);
     my $mem = Cache::Memcached->new($config);
     bless(\$mem, $class);
 }
 
 sub default_config {
+    my ($class, $namespace) = @_;
     return {
-        servers => ['127.0.0.1:11211'],
-        debug => 0
+        servers     => ['127.0.0.1:11211'],
+        debug       => 0,
+        namespace   => $namespace,
     };
 }
 
 sub fetch {
     my $self = shift;
+    die "Rejecting insanity" if @_ > 100;
     values(%{$$self->get_multi(@_)});
 }
 
@@ -34,14 +38,18 @@ sub publisher_indices {
 
 sub lock {
     my ($self, $chan) = @_;
+    warn "trying to acquire lock: $chan\n";
     for my $i (1..10) {
         return if $$self->add("$chan#lock" => 1);
+        warn "contention: $chan\n";
+        return;
         sleep 1;
     }
 }
 
 sub unlock {
     my ($self, $chan) = @_;
+    warn "trying to release lock: $chan\n";
     $$self->delete("$chan#lock");
 }
 
